==> Ambidexterity-0.0.0%2B1.21.%286-8%29-Fabric-sources.jar: eva/ambidexterity/AmbidexterityClient.java <==
package eva.ambidexterity;

import eva.ambidexterity.config.AmbidexterityConfig;
import eva.ambidexterity.init.ParticleInit;
import eva.ambidexterity.network.BalancePacket;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.fabricmc.fabric.api.client.networking.v1.ClientConfigurationConnectionEvents;
import net.fabricmc.fabric.api.client.networking.v1.ClientConfigurationNetworking;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayConnectionEvents;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_2960;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import org.lwjgl.glfw.GLFW;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static eva.ambidexterity.config.AmbidexterityConfig.isInvertWithCrouch;

public class AmbidexterityClient implements ClientModInitializer {

    public static final String MOD_ID = AmbidexterityMain.MOD_ID + "-client";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static final class_304 modBind;

    public static final class_2960 ATTACK_PACKET_ID = class_2960.method_43902("eva", "off_attack");

    private static boolean sprindicator = false;

    public static boolean sprindicator() {return sprindicator;}

    @Override
    public void onInitializeClient() {

        ParticleInit.initClient();

        sprindicator = FabricLoader.getInstance().isModLoaded("sprintindicator");

        ClientConfigurationConnectionEvents.INIT.register((handler,client) -> {
            ClientConfigurationNetworking.registerGlobalReceiver(BalancePacket.ID, (payload, context) ->
                    context.client().execute(() ->
                            AmbidexterityConfig.onBalanceReceived(payload)));
        });
        ClientPlayConnectionEvents.DISCONNECT.register((handler, client) -> {
            LOGGER.info("Removing server config");
            client.execute(AmbidexterityConfig::disconnect);
        });
        ClientConfigurationConnectionEvents.DISCONNECT.register((handler, client) -> {
            LOGGER.info("Removing server config; failed config!");
            client.execute(AmbidexterityConfig::disconnect);
            ClientConfigurationNetworking.unregisterGlobalReceiver(BalancePacket.ID);
        });
    }

    public static boolean isInverted() {
        assert class_310.method_1551().field_1724 != null;
        if (isInvertWithCrouch() && class_310.method_1551().field_1724.method_18276()) return true;
        return modBind.method_1434();
    }

    static {
        modBind = KeyBindingHelper.registerKeyBinding(
                new class_304(
                        "Ambidexterity Invert Key",
                        class_3675.class_307.field_1668,
                        GLFW.GLFW_KEY_UNKNOWN,
                        class_304.field_32139
                )
        );
    }
}

==> Ambidexterity-0.2.1%2B1.21.%286-8%29-Fabric-sources.jar: eva/ambidexterity/AmbidexterityClient.java <==
package eva.ambidexterity;

import eva.ambidexterity.config.AmbidexterityConfig;
import eva.ambidexterity.init.ParticleInit;
import eva.ambidexterity.network.BalancePacket;
import eva.ambidexterity.network.HotHandPacket;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.fabricmc.fabric.api.client.networking.v1.ClientConfigurationConnectionEvents;
import net.fabricmc.fabric.api.client.networking.v1.ClientConfigurationNetworking;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayConnectionEvents;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import org.lwjgl.glfw.GLFW;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static eva.ambidexterity.config.AmbidexterityConfig.isInvertWithCrouch;
import static eva.ambidexterity.config.AmbidexterityConfig.isToggleInvert;

public class AmbidexterityClient implements ClientModInitializer {

    public static final String MOD_ID = AmbidexterityMain.MOD_ID + "-client";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static final class_304 modBind;
    private static boolean toggle = false;

    private static boolean sprindicator = false;

    public static boolean sprindicator() {return sprindicator;}

    @Override
    public void onInitializeClient() {

        ParticleInit.initClient();

        LOGGER.info("The packets were a nightmare. Appreciate them.");

        sprindicator = FabricLoader.getInstance().isModLoaded("sprintindicator");

        ClientConfigurationConnectionEvents.INIT.register((handler,client) -> {
            ClientConfigurationNetworking.registerGlobalReceiver(BalancePacket.TYPE, (payload, context) ->
                    context.client().execute(() ->
                            AmbidexterityConfig.onBalanceReceived(payload)));
        });
        ClientPlayConnectionEvents.DISCONNECT.register((handler, client) -> {
            LOGGER.info("Removing server config");
            client.execute(AmbidexterityConfig::disconnect);
        });
        ClientConfigurationConnectionEvents.DISCONNECT.register((handler, client) -> {
            LOGGER.info("Removing server config; failed config!");
            client.execute(AmbidexterityConfig::disconnect);
            ClientConfigurationNetworking.unregisterGlobalReceiver(BalancePacket.TYPE);
        });
    }

    public static boolean isInvertedInclToggle() {
        if (isToggleInvert()) return toggle;
        return isInvertedNoToggle();
    }

    public static boolean isInvertedNoToggle() {
        if (class_310.method_1551().field_1724 != null && (isInvertWithCrouch() || modBind.method_1415()) && class_310.method_1551().field_1724.method_18276()) return true;
        return modBind.method_1434();
    }

    public static void handleTicker() {
        assert class_310.method_1551().field_1724 != null;
        if (
                (isToggleInvert() && modBind.method_1436())
                        || (
                        !isToggleInvert() &&
                                (
                                        toggle != modBind.method_1434()
                                                || (isInvertWithCrouch() && toggle != class_310.method_1551().field_1724.method_18276())
                                )
                )
        ) {
            toggle = !toggle;
            ClientPlayNetworking.send(new HotHandPacket(toggle));
        }
    }

    static {
        modBind = KeyBindingHelper.registerKeyBinding(
                new class_304(
                        "Ambidextrous Invert Key",
                        class_3675.class_307.field_1668,
                        GLFW.GLFW_KEY_UNKNOWN,
                        class_304.field_32139
                )
        );
    }
}
